Disclaimers and License
=======================

Disclaimers
-----------

**This package and documentation is not affiliated with the Federal Financial Institution Examination Council (FFIEC) or any other US Government Agency.**

Civic Forge Solutions LLC and any contributors (the "Publishers"), to this software assume no responsibility or liability for any errors or omissions in the content. The information contained is provided on an "as is" basis with no guarantees of completeness, accuracy, usefulness, or timeliness.

This package and documentation provides a tool for analyzing, processing, and acquiring Federal financial system regulatory data. This package does not offer investment advice. This package is intended and must be used for informational purposes only. The Publishers do not have access to non-public information about publicly traded companies.

License
-------

Mozilla Public License 2.0

Copyright 2025 Civic Forge Solutions LLC

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.

This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the Mozilla Public License for the specific language governing rights and limitations under the License.

